unit mickey;

(****************************************************************************)
(*  mouse unit for turbo pascal.                                            *)
(*  the comments in this unit were basically copied directly                *)
(*  from the advanced ms dos programing book, the section on                *)
(*  the microsoft mouse driver, which was the source of all                 *)
(*  the mouse interrupt functions and their parameters.                     *)
(****************************************************************************)



interface

uses dos,crt,graph;

const leftbutton=1;
      rightbutton=2;
      centerbutton=4;
      anybutton=7;
      MHard=1;
      MSoft=0;

TYPE FormePtr=^Forme;      {un curseur}
     Forme=RECORD
           ecran:ARRAY[0..15] OF WORD;
           curseur:ARRAY[0..15] OF WORD;
           ptActif:pointType; {le type point est dfini dans graph}
           END;
     rect=RECORD
          CASE Byte OF
               1:(hautGauche, basDroit : pointType);
               2:(x1, y1, x2, y2 : Integer);
          END;

VAR Reg:Registers;
    un,unbis,deux,trois,quatre,cinq,zero,tete_mort,tete_mort2,interrogation,
    main2,cbn,Standard,Fleche_petite,fleche_gauche,Fleche_droite,Main,
    Sablier1,Sablier2,Sablier3,marque,CroixR,CroixD,reticule:formePtr;
    {diffrents curseurs}
    S_Mouse:BOOLEAN;  {pour souris installe}







procedure initmouse(var buttons:word;var err:boolean);

(****************************************************************************)
(* initializes the mouse driver.                                            *)
(*  call: nothing                                                           *)
(*  returns: buttons=number of mouse buttons                                *)
(*  err=false if mouse support is available, true otherwise                 *)
(*  note:    * after a call to this function the driver is initialized to   *)
(*             the following state:                                         *)
(*     - mouse pointer at screen center and hidden.                         *)
(*     - display page is set to zero.                                       *)
(*     - mouse pointer shape set to default arrow shape in graphics modes,  *)
(*       or reverse block in text modes.                                    *)
(*     - user mouse event handlers are disabled.                            *)
(*     - light pen emulation enabled.                                       *)
(*     - mouse sensitivity set to default vales (see setmousesense)         *)
(*     - pointer limits set to entire screen.                               *)
(****************************************************************************)



procedure showpointer;

(****************************************************************************)
(* displays the mouse pointer, and cancels any pointer exclusion area.      *)
(*  call:    nothing                                                        *)
(*  returns: nothing                                                        *)
(*  note:    * a counter is maintained which is decremented by hidepointer  *)
(*             and is incremented (if nonzero) by this function.  the mouse *)
(*             pointer is displayed any time the counter is zero.  the      *)
(*             counter is set to -1 when the mouse driver is reset.         *)
(****************************************************************************)



procedure hidepointer;

(****************************************************************************)
(* removes the mouse pointer from the screen, but continues to track the    *)
(*  position of the mouse.                                                  *)
(*  call:    nothing                                                        *)
(*  returns: nothing                                                        *)
(*  note:    * see showpointer                                              *)
(****************************************************************************)



function buttonpressed(mask : word) : boolean;

(****************************************************************************)
(* returns a true value if the specified button(s) is pressed.              *)
(*  call:    mask = bit mask of desired button(s)                           *)
(*    bit(s)  significance(if set)                                          *)
(*    0       left button                                                   *)
(*    1       right button                                                  *)
(*    2       center button                                                 *)
(*    3-15    reserved(0)                                                   *)
(*  returns: true is button is pressed, false otherwise.                    *)
(*  note:    * the constants leftbutton, rightbutton, centerbutton, and     *)
(*             anybutton can be used for the bit masking.  they equal 1, 2, *)
(*             4, and 7 respectivly.                                        *)
(****************************************************************************)



procedure getmouseposition(var buttons, horiz, vert : word);

(****************************************************************************)
(* returns the current mouse button status and pointer position.            *)
(*  call:    nothing                                                        *)
(*  returns: buttons = mouse button status                                  *)
(*    horiz   = horizontal (x) coordinate                                   *)
(*    vert    = vertical (y) coordinate                                     *)
(*   note:    * coordinates are in pixels regardless of the current         *)
(*              display mode.                                               *)
(*      position (0,0) is the upper left corner of the screen.              *)
(****************************************************************************)



function mousein(x1,y1,x2,y2: word):boolean;

(****************************************************************************)
(* returns true if mouse is within rectangle with upper-left                *)
(*  corner (x1,y1) and lower-right corner (x2,y2).                          *)
(****************************************************************************)



procedure setpointerposition(horiz, vert : word);

(****************************************************************************)
(* set the position of the pointer.  the pointer is displayed in the new    *)
(*  position unless it has been hidden using hidepointer or it is an        *)
(*  exclusion area defined by setpointerexcl.                               *)
(*  call:    horiz = horizontal (x) coordinate                              *)
(*           vert  = vertical (y) coordinate                                *)
(*  returns: nothing                                                        *)
(*  notes:   * coordinates are in pixels regardless of the current          *)
(*             display mode.                                                *)
(*      position (0,0) is the upper left corner of the screen.              *)
(*    * the position is adjusted if necessary to lie within the pointer     *)
(*      limits set by setlimits.                                            *)
(****************************************************************************)



procedure getpressinfo(button : word; var stat, count, horiz, vert : word);

(****************************************************************************)
(* returns the current status of all mouse buttons, and the number of       *)
(*  presses and position of the last press for a specifed mouse button      *)
(*  since the last call to this procedure for that button.  the press       *)
(*  counter for the button is reset to zero.                                *)
(*  call:    button = button identifier                                     *)
(*      0 = left button                                                     *)
(*      1 = right button                                                    *)
(*      2 = center button                                                   *)
(*  returns: stat   = button status                                         *)
(*      bit(s)  significance(if set)                                        *)
(*      0       left button is down                                         *)
(*      1       right button is down                                        *)
(*      2       center button is down                                       *)
(*      3-15    reserved(0)                                                 *)
(*    count  = button press counter                                         *)
(*    horiz  = horizontal (x) coordinate of last button press               *)
(*    vert   = vertical (y) coordinate of last button press                 *)
(****************************************************************************)



procedure getreleaseinfo(button : word; var stat, count, horiz, vert : word);

(****************************************************************************)
(* returns the current status of all mouse buttons, and the number of       *)
(*  releases and position of the last release for a specifed mouse          *)
(*  button since the last call to this procedure for that button.  the      *)
(*  release counter for the button is reset to zero.                        *)
(*  call:    button = button identifier                                     *)
(*      0 = left button                                                     *)
(*      1 = right button                                                    *)
(*      2 = center button                                                   *)
(*  returns: stat   = button status                                         *)
(*      bit(s)  significance(if set)                                        *)
(*      0       left button is down                                         *)
(*      1       right button is down                                        *)
(*      2       center button is down                                       *)
(*      3-15    reserved(0)                                                 *)
(*    count  = button release counter                                       *)
(*    horiz  = horizontal (x) coordinate of last button release             *)
(*    vert   = vertical (y) coordinate of last button release               *)
(****************************************************************************)



procedure setlimits(hormin, hormax, vermin, vermax : word);

(****************************************************************************)
(* limits the mouse pointer to stay within a certain area.                  *)
(*  call:    hormin = minimum horizontal (x) coordinate                     *)
(*    hormax = maximum horizontal (x) coordinate                            *)
(*    vermin = minimum vertical (y) coordinate                              *)
(*    vermax = maximum vertical (y) coordinate                              *)
(*  returns: nothing                                                        *)
(*  note:    * if both hormin and hormax are zero then then the previous    *)
(*             horizontal limits remain unchanged; the same is true for     *)
(*             vermin and vermax.                                           *)
(****************************************************************************)



procedure setpointershape(laforme:formeptr);

(****************************************************************************)
(* defines the shape, color, and hot spot of the pointer in graphics        *)
(*  modes.                                                                  *)
(*  call:    buffer = pointer to mouse pointer image buffer                 *)
(*  returns: nothing                                                        *)
(*  note:    * the pointer image buffer is 64 bytes long.  the first 32     *)
(*             bytes contain a bit mask which is anded with the screen      *)
(*             image, and the remaining 32 bytes are then xored with the    *)
(*             screen image.                                                *)
(*    * the hot spot is relative to the upper left corner of the pointer    *)
(*      image, and each offset must be in the range -16 to 16.  in display  *)
(*      modes 4 and 5, the horizontal offset must be an even number.        *)
(****************************************************************************)



procedure getmotioncount(var horiz, vert : word);

(****************************************************************************)
(* returns the net mouse displacement since the last call to this           *)
(*  procedure.  the returned value is in mickeys; a positive number         *)
(*  indicates travel to the right or downwards, a negative number           *)
(*  indicates travel to the left or upwards.  one mickey represents         *)
(*  approximately 1/200 of an inch of mouse movement.                       *)
(*  call:    nothing                                                        *)
(*  returns: horiz = horizontal (x) mickey count                            *)
(*    vert  = vertical (y) mickey count                                     *)
(****************************************************************************)



procedure seteventhandler(eventmask : word; handler : pointer);

(****************************************************************************)
(* sets the address and event mask for an application program's mouse       *)
(*  event handler.  the handler is called by the mouse driver whenever      *)
(*  the specifed mouse events occur.                                        *)
(*  call:    eventmask = event mask                                         *)
(*         bit(s)  significance(if set)                                     *)
(*         0       mouse movement                                           *)
(*         1       left button pressed                                      *)
(*         2       left button released                                     *)
(*         3       right button pressed                                     *)
(*         4       right button released                                    *)
(*         5       center button pressed                                    *)
(*         6       center button released                                   *)
(*         7-15    reserved(0)                                              *)
(*    handler   = pointer to the handler procedure                          *)
(*  returns: nothing                                                        *)
(*  notes:   * the user-defined handler is entered from the mouse driver    *)
(*             by a far call with the registers set up as follows:          *)
(*      ax       mouse event flags (see event mask)                         *)
(*      bx       button state                                               *)
(*        bit(s)  significance(if set)                                      *)
(*        0       left button is down                                       *)
(*        1       right button is down                                      *)
(*        2       center button is down                                     *)
(*        3-15    reserved(0)                                               *)
(*      cx       horizontal (x) pointer coordinate                          *)
(*      dx       vertical (y) pointer coordinate                            *)
(*      si       last raw vertical mickey count                             *)
(*      di       last raw horizontal mickey count                           *)
(*      ds       mouse driver data segment                                  *)
(*    * if an event does not generate a call to the user-defined handler    *)
(*      because its bit is not set in the event mask, it is still reported  *)
(*      in the event falgs during calls to the handler for events which     *)
(*      are enabled.                                                        *)
(****************************************************************************)




procedure setpointerexcl(hormin, vermin, hormax, vermax : word);

(****************************************************************************)
(* defines an exclusion area for the mouse pointer.  when the mouse         *)
(*  pointer lies within the specified area, it is not displayed.            *)
(*  call:    hormin = upper left x coordinate                               *)
(*    vermin = upper left y coordinate                                      *)
(*    hormax = lower right x coordinate                                     *)
(*    vermax = lower right y coordinate                                     *)
(*  returns: nothing                                                        *)
(*  note:    *  the exclusion area is replaced by another call to this      *)
(*       procdure or cancelled by initmouse and showpointer.                *)
(****************************************************************************)



procedure swapeventhandlers(var mask : word; var buffer : pointer);

(****************************************************************************)
(* set the address and event mask for an application program's mouse        *)
(*  event handler and returns the address and event mask for the previous   *)
(*  handler.  the newly installed handler is called by the mouse driver     *)
(*  whenever the specified mouse events occur.                              *)
(*  call:    mask    = event mask                                           *)
(*       bit(s)  significance(if set)                                       *)
(*       0       mouse movement                                             *)
(*       1       left button pressed                                        *)
(*       2       left button released                                       *)
(*       3       right button pressed                                       *)
(*       4       right button released                                      *)
(*       5       center button pressed                                      *)
(*       6       center button released                                     *)
(*       7-15    reserved(0)                                                *)
(*    handler = pointer to the handler procedure                            *)
(*  returns: mask    = previous event mask                                  *)
(*           handler = pointer to previous handler                          *)
(*  notes:   * the notes for seteventhandler describe the information       *)
(*             passed to the user-defined event handler.  also see          *)
(*             setalteventhandler.                                          *)
(*    * calls to the event handler are disabled with initmouse or by        *)
(*      setting an event mask of zero.                                      *)
(****************************************************************************)



function getsavestatesize : word;

(****************************************************************************)
(* returns the size of the buffer required to store the current state of    *)
(*  the mouse driver.                                                       *)
(*  note:    * also see savedrvrstate and restoredrvrstate.                 *)
(****************************************************************************)



procedure savedrvrstate(buffer : pointer);

(****************************************************************************)
(* saves the mouse driver state in a user buffer.  the minimum size for     *)
(*  the buffer must be determined by getsavestatesize.                      *)
(*  call:    buffer = pointer to the user defined buffer.                   *)
(*  returns: nothing                                                        *)
(*  note:    * use this procedure before executing a child program          *)
(*             (exec), in case the child also uses the mouse. after         *)
(*             the exec call, restore the previous mouse driver state       *)
(*             using restoredrvrstate.                                      *)
(****************************************************************************)



procedure restoredrvrstate(buffer : pointer);

(****************************************************************************)
(* restores the mouse driver state from a user buffer.                      *)
(*  call:    buffer = pointer to the user defined buffer.                   *)
(*  returns: nothing                                                        *)
(*  note:    * the mouse driver state must have been previously saved       *)
(*             into the same buffer with savedrvrstate.  the format of      *)
(*             the data in the buffer in undocumented and subject to        *)
(*             change.                                                      *)
(****************************************************************************)



procedure setalteventhandler(mask: word; handler: pointer; var err: boolean);

(****************************************************************************)
(* sets the address and event mask for an application program's mouse       *)
(*  event handler.  as many as three handlers with distinct event masks     *)
(*  can be registered with this function.  when an event occurs that        *)
(*  matches one of the masks, the corresponding handler is called by        *)
(*  the mouse driver.                                                       *)
(*  call:    mask    = event mask                                           *)
(*       bit(s)  significance(if set)                                       *)
(*       0       mouse movement                                             *)
(*       1       left button pressed                                        *)
(*       2       left button released                                       *)
(*       3       right button pressed                                       *)
(*       4       right button released                                      *)
(*       5       shift key pressed during button press or release           *)
(*       6       ctrl key pressed during button press or release            *)
(*       7       alt key pressed during button press or release             *)
(*       8-15    reserved(0)                                                *)
(*    handler = pointer to the handler procedure                            *)
(*  returns: err     = false if successful, true otherwise                  *)
(*  notes:   * when this procedure is called, at least one of the bits 5,   *)
(*             6, and 7 must be set in mask.                                *)
(*    * the user-defined handler is entered from the mouse driver by a      *)
(*      far call with the registers set up as follows:                      *)
(*      ax       mouse event flags (see event mask)                         *)
(*      bx       button state                                               *)
(*        bit(s)  significance(if set)                                      *)
(*        0       left button is down                                       *)
(*        1       right button is down                                      *)
(*        2       center button is down                                     *)
(*        3-15    reserved(0)                                               *)
(*      cx       horizontal (x) pointer coordinate                          *)
(*      dx       vertical (y) pointer coordinate                            *)
(*      si       last raw vertical mickey count                             *)
(*      di       last raw horizontal mickey count                           *)
(*      ds       mouse driver data segment                                  *)
(*    * if an event does not generate a call to the user-defined handler    *)
(*      because its bit is not set in the event mask, it is still reported  *)
(*      in the event falgs during calls to the handler for events which     *)
(*      are enabled.                                                        *)
(*    * calls to the handler are disabled with initmouse.                   *)
(*    * also see seteventhandler and swapeventhandlers.                     *)
(****************************************************************************)



procedure getalteventadrs(var mask:word;var handler:pointer;var err:boolean);

(****************************************************************************)
(* returns the address for the mouse event handler matching the specified   *)
(*  event mask.                                                             *)
(*  call:    mask    = event mask                                           *)
(*       (see setalteventhandler)                                           *)
(*  returns: mask    = event mask                                           *)
(*    handler = pointer to the alternate event handler                      *)
(*    err     = false if successful, true if not successful (no handler     *)
(*       installed or event mask does not match any installed               *)
(*       handler.                                                           *)
(*  note:    * setalteventhandler allows as many as three event handler with*)
(*      distinct event masks to be installed.  this procedure can be        *)
(*      called to search for a handler that matches a specific event, so    *)
(*      that it can be replaced or disabled.                                *)
(****************************************************************************)



procedure setmousesense(horiz, vert, double : word);

(****************************************************************************)
(* set the number of mickeys per 8 pixels for horizontal and vertical mouse *)
(* motion and the threshold speed for doubleing pointer motion on the       *)
(* screen. one mickey equals approximately 1/200 of an inch of mouse travel.*)
(*  call:    horiz  = horizontal mickeys (1-32,767; default=8)              *)
(*    vert   = vertical mickeys (1-32,767; default=16)                      *)
(*    double = double speed threshold in mickeys/second (default=64);       *)
(*  returns: nothing                                                        *)
(****************************************************************************)



procedure getmousesense(var horiz, vert, double : word);

(****************************************************************************)
(* return the current mickeys to pixels ratios for vertical and horizontal  *)
(*  screen movement and the threshold speed for doubling of pointer motion. *)
(*  call:    nothing                                                        *)
(*  returns: horiz  = horizontal mickeys (1-32,767; default=8)              *)
(*    vert   = vertical mickeys (1-32,767; default=16)                      *)
(*    double = double speed threshold in mickeys/second (default=64);       *)
(****************************************************************************)



procedure setmouseintr(flags : word);

(****************************************************************************)
(* sets the rate at which the mouse driver polls the status of the mouse.   *)
(*  faster rates provide better resolution in graphics mode but may degrade *)
(*  the performance of application programs.                                *)
(*  call:    flags = interrupt rate flags                                   *)
(*     bit(s)    significance(if set)                                       *)
(*     0         no interrupts allowed                                      *)
(*     1         30 interrupts/second                                       *)
(*     2         50 interrupts/second                                       *)
(*     3         100 interrupts/second                                      *)
(*     4         200 interrupts/second                                      *)
(*     5-15      reserved(0)                                                *)
(*  returns: nothing                                                        *)
(*  notes:   * this procedure is applicable for the inport mouse only.      *)
(*    * in more than one bit is set in flags, the lowest order bit          *)
(*      prevails.                                                           *)
(****************************************************************************)



procedure setpointerpage(page : word);

(****************************************************************************)
(* selects the display page for the mouse pointer.                          *)
(*  call:    page = display page                                            *)
(*  returns: nothing                                                        *)
(*  note:    * the valid page numbers depend on the current display mode.   *)
(****************************************************************************)



function getpointerpage : word;

(****************************************************************************)
(* returns the current display page for the mouse pointer.                  *)
(****************************************************************************)



procedure disablemousedrvr(var handler : pointer; var err : boolean);

(****************************************************************************)
(* disables the mouse driver and returns the address of the previous int 33h*)
(*  handler.                                                                *)
(*  call:    nothing                                                        *)
(*  returns: handler = pointer to previous int 33h handler                  *)
(*    err     = false if successful, true otherwise                         *)
(*  notes:   * when this procedure is called, the mouse driver releases any *)
(*      interrupt vectors it hase captured other than int 33h (which may    *)
(*      be int 10h, int 71h, and/or int 74h).  the application program      *)
(*      can complete the process of logically removing the mouse driver     *)
(*      by restoring the original contents of the int 33h vector with       *)
(*      setintvec using the pointer returned by the procedure.              *)
(*    * also see enablemousedrvr.                                           *)
(****************************************************************************)



procedure enablemousedrvr;

(****************************************************************************)
(* enables the mouse driver and the servicing fo mouse interrupts.          *)
(*  call:    nothing                                                        *)
(*  returns: nothing                                                        *)
(*  note:    * also see disablemousedrvr                                    *)
(****************************************************************************)



procedure resetmousedrvr(var buttons : word; var err : boolean);

(****************************************************************************)
(* resets the mouse driver and returns driver status.  if the mouse pointer *)
(* was previously visible, is is removed trom the screen, and any presoiusly*)
(*  installed user event handlers for mouse events are disabled.            *)
(*  call:    nothing                                                        *)
(*  returns: buttons = number of mouse buttons                              *)
(*    err     = false if mouse support is available, true otherwise         *)
(*  note:    * this procedure differ from initmouse in that there is no     *)
(*      initialization of the mouse hardware.                               *)
(****************************************************************************)



procedure setmouselang(langnumber : word);

(****************************************************************************)
(* selects the language that will be used by the mouse driver for prompts   *)
(*  and error messages.                                                     *)
(*  call:    langnumber = language number                                   *)
(*   0 = english                                                            *)
(*   1 = french                                                             *)
(*   2 = dutch                                                              *)
(*   3 = german                                                             *)
(*   4 = swedish                                                            *)
(*   5 = finnish                                                            *)
(*   6 = spanish                                                            *)
(*   7 = portuguese                                                         *)
(*   8 = italian                                                            *)
(*  returns: nothing                                                        *)
(* note:    * this procedure is only functional in international versions of*)
(*      the microsoft mouse drive.                                          *)
(****************************************************************************)



function getmouselang : word;

(****************************************************************************)
(* returns the number of the language that is used by the mouse driver for  *)
(*  prompts and error messages.                                             *)
(*  call:    nothing                                                        *)
(*  returns: language number (see above)                                    *)
(* note:    * this procedure is only functional in international versions of*)
(*      the microsoft mouse drive.                                          *)
(****************************************************************************)



procedure getmouseinfo(var majver, minver, mousetype, irq : word);

(****************************************************************************)
(* returns the mouse driver version number, mouse type, and the irq number  *)
(*  of the interrupt used by the mouse adapter.                             *)
(*  call:    nothing                                                        *)
(*  returns: majver    = major version number (6 for version 6.10, etc.)    *)
(*    minver    = minor version number (10 for version 6.10, etc.)          *)
(*    mousetype = mouse type                                                *)
(*         1 = bus mouse                                                    *)
(*         2 = serial mouse                                                 *)
(*         3 = inport mouse                                                 *)
(*         4 = ps/2 mouse                                                   *)
(*         5 = hp mouse                                                     *)
(*    irq       = irq number                                                *)
(*         0                = ps/2                                          *)
(*         2, 3, 4, 5, or 7 = irq number                                    *)
(****************************************************************************)



(****************************************************************************)
(******************************* IMPLEMANTATION *****************************)
(****************************************************************************)

implementation

const mouseint=$33;
      curs:BOOLEAN=FALSE;

var c:char;






PROCEDURE definitun;
BEGIN
     WITH un^ DO
     BEGIN
          ecran[0]  := $FFFF;        { 1111111111111111 }
          ecran[1]  := $FFFF;        { 1111111111111111 }
          ecran[2]  := $F1FF;        { 1111000111111111 }
          ecran[3]  := $E1FF;        { 1110000111111111 }
          ecran[4]  := $E1FF;        { 1110000111111111 }
          ecran[5]  := $E1FF;        { 1110000111111111 }
          ecran[6]  := $E0FF;        { 1110000011111111 }
          ecran[7]  := $8020;        { 1000000000100000 }
          ecran[8]  := $0000;        { 0000000000000000 }
          ecran[9]  := $8000;        { 1000000000000000 }
          ecran[10] := $0000;        { 0000000000000000 }
          ecran[11] := $8000;        { 1000000000000000 }
          ecran[12] := $0000;        { 0000000000000000 }
          ecran[13] := $8000;        { 1000000000000000 }
          ecran[14] := $0000;        { 0000000000000000 }
          ecran[15] := $8020;        { 1000000000100000 }

          curseur[0]  := $0000;      { 0000000000000000 }
          curseur[1]  := $0000;      { 0000000000000000 }
          curseur[2]  := $0000;      { 0000000000000000 }
          curseur[3]  := $0C00;      { 0000110000000000 }
          curseur[4]  := $0C00;      { 0000110000000000 }
          curseur[5]  := $0C00;      { 0000110000000000 }
          curseur[6]  := $0C00;      { 0000110000000000 }
          curseur[7]  := $0E00;      { 0000111000000000 }
          curseur[8]  := $7F8E;      { 0111111110001110 }
          curseur[9]  := $1FEE;      { 0001111111101110 }
          curseur[10] := $7FEE;      { 0111111111101110 }
          curseur[11] := $1FEE;      { 0001111111101110 }
          curseur[12] := $7FEE;      { 0111111111101110 }
          curseur[13] := $1FEA;      { 0001111111101010 }
          curseur[14] := $7F8E;      { 0111111111001110 }
          curseur[15] := $0000;      { 0000000000000000 }
          ptActif.x := 4;
          ptActif.y := 3;
     END;
END;

PROCEDURE definitunbis;
BEGIN
     WITH unbis^ DO
     BEGIN
          ecran[0]  := $FFFF;        { 1111111111111111 }
          ecran[1]  := $FFFF;        { 1111111111111111 }
          ecran[2]  := $FFFF;        { 1111111111111111 }
          ecran[3]  := $EFFF;        { 1111111111111111 }
          ecran[4]  := $E7FF;        { 1110011111111111 }
          ecran[5]  := $C3FF;        { 1100001111111111 }
          ecran[6]  := $81FF;        { 1000000111111111 }
          ecran[7]  := $8020;        { 1000000000100000 }
          ecran[8]  := $0000;        { 0000000000000000 }
          ecran[9]  := $8000;        { 1000000000000000 }
          ecran[10] := $0000;        { 0000000000000000 }
          ecran[11] := $8000;        { 1000000000000000 }
          ecran[12] := $0000;        { 0000000000000000 }
          ecran[13] := $8000;        { 1000000000000000 }
          ecran[14] := $0000;        { 0000000000000000 }
          ecran[15] := $8020;        { 1000000000100000 }

          curseur[0]  := $0000;      { 0000000000000000 }
          curseur[1]  := $0000;      { 0000000000000000 }
          curseur[2]  := $0000;      { 0000000000000000 }
          curseur[3]  := $0000;      { 0000000000000000 }
          curseur[4]  := $0000;      { 0000000000000000 }
          curseur[5]  := $1800;      { 0001100000000000 }
          curseur[6]  := $3C00;      { 0011110000000000 }
          curseur[7]  := $0E00;      { 0000111000000000 }
          curseur[8]  := $7F8E;      { 0111111110001110 }
          curseur[9]  := $1FEE;      { 0001111111101110 }
          curseur[10] := $7FEE;      { 0111111111101110 }
          curseur[11] := $1FEE;      { 0001111111101110 }
          curseur[12] := $7FEE;      { 0111111111101110 }
          curseur[13] := $1FEA;      { 0001111111101010 }
          curseur[14] := $7F8E;      { 0111111111001110 }
          curseur[15] := $0000;      { 0000000000000000 }
          ptActif.x := 4;
          ptActif.y := 3;
     END;
END;


PROCEDURE definitdeux;
BEGIN
     WITH deux^ DO
     BEGIN
          ecran[0]  := $FFFF;        { 1111111111111111 }
          ecran[1]  := $FFFF;        { 1111111111111111 }
          ecran[2]  := $FFFF;        { 1111111111111111 }
          ecran[3]  := $FBBF;        { 1111111111111111 }
          ecran[4]  := $F11F;        { 1111111111111111 }
          ecran[5]  := $F11F;        { 1111111111111111 }
          ecran[6]  := $F11F;        { 1111111111111111 }
          ecran[7]  := $F007;        { 1111111111111111 }
          ecran[8]  := $F803;        { 1111111111111111 }
          ecran[9]  := $E003;        { 1111111111111111 }
          ecran[10] := $C003;        { 1111111111111111 }
          ecran[11] := $C003;        { 1111111111111111 }
          ecran[12] := $C003;        { 1111111111111111 }
          ecran[13] := $C003;        { 1111111111111111 }
          ecran[14] := $C003;        { 1111111111111111 }
          ecran[15] := $E007;        { 1111111111111111 }


          curseur[0]  := $0000;      { 0000000000000000 }
          curseur[1]  := $0000;      { 0000000000000000 }
          curseur[2]  := $0000;      { 0000000000000000 }
          curseur[3]  := $0000;      { 0000000000000000 }
          curseur[4]  := $0440;      { 0000000000000000 }
          curseur[5]  := $0440;      { 0000000000000000 }
          curseur[6]  := $0440;      { 0000000000000000 }
          curseur[7]  := $06C0;      { 0000000000000000 }
          curseur[8]  := $02A8;      { 0000000000000000 }
          curseur[9]  := $02A8;      { 0000000000000000 }
          curseur[10] := $13F8;      { 0000000000000000 }
          curseur[11] := $13F8;      { 0000000000000000 }
          curseur[12] := $1FF8;      { 0000000000000000 }
          curseur[13] := $1FF8;      { 0000000000000000 }
          curseur[14] := $0FF0;      { 0000000000000000 }
          curseur[15] := $0000;      { 0000000000000000 }
          ptActif.x := 8;
          ptActif.y := 11;
     END;
END;


PROCEDURE definittrois;
BEGIN
     WITH trois^ DO
     BEGIN
          ecran[0]  := $FFFF;        { 1111111111111111 }
          ecran[1]  := $FFFF;        { 1111111111111111 }
          ecran[2]  := $FFFF;        { 1111111111111111 }
          ecran[3]  := $FB6F;        { 1111111111111111 }
          ecran[4]  := $F007;        { 1111111111111111 }
          ecran[5]  := $F007;        { 1111111111111111 }
          ecran[6]  := $F007;        { 1111111111111111 }
          ecran[7]  := $F007;        { 1111111111111111 }
          ecran[8]  := $F803;        { 1111111111111111 }
          ecran[9]  := $C003;        { 1111111111111111 }
          ecran[10] := $C003;        { 1111111111111111 }
          ecran[11] := $C003;        { 1111111111111111 }
          ecran[12] := $C003;        { 1111111111111111 }
          ecran[13] := $C003;        { 1111111111111111 }
          ecran[14] := $C003;        { 1111111111111111 }
          ecran[15] := $E007;        { 1111111111111111 }


          curseur[0]  := $0000;      { 0000000000000000 }
          curseur[1]  := $0000;      { 0000000000000000 }
          curseur[2]  := $0000;      { 0000000000000000 }
          curseur[3]  := $0000;      { 0000000000000000 }
          curseur[4]  := $0490;      { 0000000000000000 }
          curseur[5]  := $0490;      { 0000000000000000 }
          curseur[6]  := $0490;      { 0000000000000000 }
          curseur[7]  := $06B0;      { 0000000000000000 }
          curseur[8]  := $02A8;      { 0000000000000000 }
          curseur[9]  := $02A8;      { 0000000000000000 }
          curseur[10] := $13F8;      { 0000000000000000 }
          curseur[11] := $13F8;      { 0000000000000000 }
          curseur[12] := $1FF8;      { 0000000000000000 }
          curseur[13] := $1FF8;      { 0000000000000000 }
          curseur[14] := $0FF0;      { 0000000000000000 }
          curseur[15] := $0000;      { 0000000000000000 }
          ptActif.x := 8;
          ptActif.y := 11;
     END;
END;


PROCEDURE definitquatre;
BEGIN
     WITH quatre^ DO
     BEGIN
          ecran[0]  := $FFFF;        { 1111111111111111 }
          ecran[1]  := $FFFF;        { 1111111111111111 }
          ecran[2]  := $FFFF;        { 1111111111111111 }
          ecran[3]  := $FB6F;        { 1111111111111111 }
          ecran[4]  := $F007;        { 1111111111111111 }
          ecran[5]  := $F003;        { 1111111111111111 }
          ecran[6]  := $F001;        { 1111111111111111 }
          ecran[7]  := $F001;        { 1111111111111111 }
          ecran[8]  := $F801;        { 1111111111111111 }
          ecran[9]  := $E003;        { 1111111111111111 }
          ecran[10] := $C003;        { 1111111111111111 }
          ecran[11] := $C003;        { 1111111111111111 }
          ecran[12] := $C003;        { 1111111111111111 }
          ecran[13] := $C003;        { 1111111111111111 }
          ecran[14] := $C003;        { 1111111111111111 }
          ecran[15] := $E007;        { 1111111111111111 }


          curseur[0]  := $0000;      { 0000000000000000 }
          curseur[1]  := $0000;      { 0000000000000000 }
          curseur[2]  := $0000;      { 0000000000000000 }
          curseur[3]  := $0000;      { 0000000000000000 }
          curseur[4]  := $0490;      { 0000000000000000 }
          curseur[5]  := $0490;      { 0000000000000000 }
          curseur[6]  := $0494;      { 0000000000000000 }
          curseur[7]  := $06B4;      { 0000000000000000 }
          curseur[8]  := $02AC;      { 0000000000000000 }
          curseur[9]  := $02A8;      { 0000000000000000 }
          curseur[10] := $13F8;      { 0000000000000000 }
          curseur[11] := $13F8;      { 0000000000000000 }
          curseur[12] := $1FF8;      { 0000000000000000 }
          curseur[13] := $1FF8;      { 0000000000000000 }
          curseur[14] := $0FF0;      { 0000000000000000 }
          curseur[15] := $0000;      { 0000000000000000 }
          ptActif.x := 8;
          ptActif.y := 11;
     END;
END;


PROCEDURE definitcinq;
BEGIN
     WITH cinq^ DO
     BEGIN
          ecran[0]  := $FFFF;        { 1111111111111111 }
          ecran[1]  := $FFFF;        { 1111111111111111 }
          ecran[2]  := $FFFF;        { 1111111111111111 }
          ecran[3]  := $FB6F;        { 1111111111111111 }
          ecran[4]  := $F007;        { 1111111111111111 }
          ecran[5]  := $F003;        { 1111111111111111 }
          ecran[6]  := $F001;        { 1111111111111111 }
          ecran[7]  := $F001;        { 1111111111111111 }
          ecran[8]  := $B801;        { 1111111111111111 }
          ecran[9]  := $1803;        { 1111111111111111 }
          ecran[10] := $0003;        { 1111111111111111 }
          ecran[11] := $8003;        { 1111111111111111 }
          ecran[12] := $8003;        { 1111111111111111 }
          ecran[13] := $C003;        { 1111111111111111 }
          ecran[14] := $C003;        { 1111111111111111 }
          ecran[15] := $E007;        { 1111111111111111 }


          curseur[0]  := $0000;      { 0000000000000000 }
          curseur[1]  := $0000;      { 0000000000000000 }
          curseur[2]  := $0000;      { 0000000000000000 }
          curseur[3]  := $0000;      { 0000000000000000 }
          curseur[4]  := $0490;      { 0000000000000000 }
          curseur[5]  := $0490;      { 0000000000000000 }
          curseur[6]  := $0494;      { 0000000000000000 }
          curseur[7]  := $06B4;      { 0000000000000000 }
          curseur[8]  := $02AC;      { 0000000000000000 }
          curseur[9]  := $42A8;      { 0000000000000000 }
          curseur[10] := $63F8;      { 0000000000000000 }
          curseur[11] := $23F8;      { 0000000000000000 }
          curseur[12] := $3FF8;      { 0000000000000000 }
          curseur[13] := $1FF8;      { 0000000000000000 }
          curseur[14] := $0FF0;      { 0000000000000000 }
          curseur[15] := $0000;      { 0000000000000000 }
          ptActif.x := 8;
          ptActif.y := 11;
     END;
END;


PROCEDURE definitzero;
BEGIN
     WITH zero^ DO
     BEGIN
          ecran[0]  := $FFFF;        { 1111111111111111 }
          ecran[1]  := $FFFF;        { 1111111111111111 }
          ecran[2]  := $FFFF;        { 1111111111111111 }
          ecran[3]  := $FFFF;        { 1111111111111111 }
          ecran[4]  := $FFFF;        { 1111111111111111 }
          ecran[5]  := $FFFF;        { 1111111111111111 }
          ecran[6]  := $FFFF;        { 1111111111111111 }
          ecran[7]  := $FD57;        { 1111111111111111 }
          ecran[8]  := $F803;        { 1111111111111111 }
          ecran[9]  := $E003;        { 1111111111111111 }
          ecran[10] := $C003;        { 1111111111111111 }
          ecran[11] := $C003;        { 1111111111111111 }
          ecran[12] := $C003;        { 1111111111111111 }
          ecran[13] := $C003;        { 1111111111111111 }
          ecran[14] := $C003;        { 1111111111111111 }
          ecran[15] := $E007;        { 1111111111111111 }


          curseur[0]  := $0000;      { 0000000000000000 }
          curseur[1]  := $0000;      { 0000000000000000 }
          curseur[2]  := $0000;      { 0000000000000000 }
          curseur[3]  := $0000;      { 0000000000000000 }
          curseur[4]  := $0000;      { 0000000000000000 }
          curseur[5]  := $0000;      { 0000000000000000 }
          curseur[6]  := $0000;      { 0000000000000000 }
          curseur[7]  := $0000;      { 0000000000000000 }
          curseur[8]  := $02A8;      { 0000000000000000 }
          curseur[9]  := $02A8;      { 0000000000000000 }
          curseur[10] := $13F8;      { 0000000000000000 }
          curseur[11] := $13F8;      { 0000000000000000 }
          curseur[12] := $1FF8;      { 0000000000000000 }
          curseur[13] := $1FF8;      { 0000000000000000 }
          curseur[14] := $0FF0;      { 0000000000000000 }
          curseur[15] := $0000;      { 0000000000000000 }
          ptActif.x := 8;
          ptActif.y := 11;
     END;
END;



PROCEDURE definitinterrogation;
BEGIN
     WITH interrogation^ DO
     BEGIN
          ecran[0]  := $E007;        { 1110000000000111 }
          ecran[1]  := $C003;        { 1100000000000011 }
          ecran[2]  := $C003;        { 1100000000000011 }
          ecran[3]  := $C003;        { 1100000000000011 }
          ecran[4]  := $C3C3;        { 1100001111000011 }
          ecran[5]  := $C3C3;        { 1100001111000011 }
          ecran[6]  := $E387;        { 1110001110000111 }
          ecran[7]  := $FF0F;        { 1111111100001111 }
          ecran[8]  := $FE1F;        { 1111111000011111 }
          ecran[9]  := $FE1F;        { 1111111000011111 }
          ecran[10] := $FE1F;        { 1111111000011111 }
          ecran[11] := $FE1F;        { 1111111000011111 }
          ecran[12] := $FC0F;        { 1111110000001111 }
          ecran[13] := $FC0F;        { 1111110000001111 }
          ecran[14] := $FC0F;        { 1111110000001111 }
          ecran[15] := $FE1F;        { 1111111000011111 }

          curseur[0]  := $0000;      { 0000000000000000 }
          curseur[1]  := $0FF0;      { 0000111111110000 }
          curseur[2]  := $1FF8;      { 0001111111111000 }
          curseur[3]  := $1818;      { 0001100000011000 }
          curseur[4]  := $1818;      { 0001100000011000 }
          curseur[5]  := $0818;      { 0000100000011000 }
          curseur[6]  := $0030;      { 0000000000110000 }
          curseur[7]  := $0060;      { 0000000001100000 }
          curseur[8]  := $00C0;      { 0000000011000000 }
          curseur[9]  := $00C0;      { 0000000011000000 }
          curseur[10] := $00C0;      { 0000000011000000 }
          curseur[11] := $0000;      { 0000000000000000 }
          curseur[12] := $00C0;      { 0000000011000000 }
          curseur[13] := $01E0;      { 0000000111100000 }
          curseur[14] := $00C0;      { 0000000011000000 }
          curseur[15] := $0000;      { 0000000000000000 }
          ptActif.x := 8;
          ptActif.y := 13;
     END;
END;



PROCEDURE definittete_mort;
BEGIN
     WITH tete_mort^ DO
     BEGIN
          ecran[0]  := $F01F;        { 1111000000011111 }
          ecran[1]  := $E00F;        { 1110000000001111 }
          ecran[2]  := $C007;        { 1100000000000111 }
          ecran[3]  := $C007;        { 1100000000000111 }
          ecran[4]  := $C007;        { 1100000000000111 }
          ecran[5]  := $C007;        { 1100000000000111 }
          ecran[6]  := $C007;        { 1100000000000111 }
          ecran[7]  := $E00F;        { 1110000000001111 }
          ecran[8]  := $0018;        { 0000000000011000 }
          ecran[9]  := $0000;        { 0000000000000000 }
          ecran[10] := $0000;        { 0000000000000000 }
          ecran[11] := $8000;        { 1000000000000000 }
          ecran[12] := $0003;        { 0000000000000011 }
          ecran[13] := $0000;        { 0000000000000000 }
          ecran[14] := $0180;        { 0000000110000000 }
          ecran[15] := $1FE0;        { 0001111111100000 }

          curseur[0]  := $0000;      { 0000000000000000 }
          curseur[1]  := $07C0;      { 0000011111000000 }
          curseur[2]  := $0FE0;      { 0000111111100000 }
          curseur[3]  := $1930;      { 0001100100110000 }
          curseur[4]  := $1930;      { 0001100100110000 }
          curseur[5]  := $1FF0;      { 0001111111110000 }
          curseur[6]  := $0C60;      { 0000110001100000 }
          curseur[7]  := $07C0;      { 0000011111000000 }
          curseur[8]  := $0540;      { 0000010101000000 }
          curseur[9]  := $6002;      { 0110000000000010 }
          curseur[10] := $3C1E;      { 0011110000011110 }
          curseur[11] := $00F0;      { 0000000011110000 }
          curseur[12] := $0780;      { 0000011110000000 }
          curseur[13] := $7C38;      { 0111110000111000 }
          curseur[14] := $400E;      { 0100000000001110 }
          curseur[15] := $0000;      { 0000000000000000 }
          ptActif.x := 7;
          ptActif.y := 8;
     END;
END;



PROCEDURE definittete_mort2;
BEGIN
     WITH tete_mort2^ DO
     BEGIN
          ecran[0]  := $F01F;        { 1111000000011111 }
          ecran[1]  := $E00F;        { 1110000000001111 }
          ecran[2]  := $C007;        { 1100000000000111 }
          ecran[3]  := $C007;        { 1100000000000111 }
          ecran[4]  := $C007;        { 1100000000000111 }
          ecran[5]  := $C007;        { 1100000000000111 }
          ecran[6]  := $C007;        { 1100000000000111 }
          ecran[7]  := $E00F;        { 1110000000001111 }
          ecran[8]  := $0018;        { 0000000000011000 }
          ecran[9]  := $0000;        { 0000000000000000 }
          ecran[10] := $0000;        { 0000000000000000 }
          ecran[11] := $8000;        { 1000000000000000 }
          ecran[12] := $0003;        { 0000000000000011 }
          ecran[13] := $0000;        { 0000000000000000 }
          ecran[14] := $0180;        { 0000000110000000 }
          ecran[15] := $1FE0;        { 0001111111100000 }

          curseur[0]  := $0000;      { 0000000000000000 }
          curseur[1]  := $07C0;      { 0000011111000000 }
          curseur[2]  := $0FE0;      { 0000111111100000 }
          curseur[3]  := $19F0;      { 0001100111110000 }
          curseur[4]  := $19F0;      { 0001100111110000 }
          curseur[5]  := $1FF0;      { 0001111111110000 }
          curseur[6]  := $0C60;      { 0000110001100000 }
          curseur[7]  := $07C0;      { 0000011111000000 }
          curseur[8]  := $0540;      { 0000010101000000 }
          curseur[9]  := $6002;      { 0110000000000010 }
          curseur[10] := $3C1E;      { 0011110000011110 }
          curseur[11] := $00F0;      { 0000000011110000 }
          curseur[12] := $0780;      { 0000011110000000 }
          curseur[13] := $7C38;      { 0111110000111000 }
          curseur[14] := $400E;      { 0100000000001110 }
          curseur[15] := $0000;      { 0000000000000000 }
          ptActif.x := 7;
          ptActif.y := 8;
     END;
END;





{}
{    Dfinit un curseur souris en forme de flche incline classique.       }
{}
PROCEDURE definitStandard;
BEGIN
     WITH Standard^ DO
     BEGIN
          ecran[0]    := $3FFF; { 0011111111111111 }
          ecran[1]    := $1FFF; { 0001111111111111 }
          ecran[2]    := $0FFF; { 0000111111111111 }
          ecran[3]    := $07FF; { 0000011111111111 }
          ecran[4]    := $03FF; { 0000001111111111 }
          ecran[5]    := $01FF; { 0000000111111111 }
          ecran[6]    := $00FF; { 0000000011111111 }
          ecran[7]    := $007F; { 0000000001111111 }
          ecran[8]    := $003F; { 0000000000111111 }
          ecran[9]    := $001F; { 0000000000011111 }
          ecran[10]   := $003F; { 0000000111111111 }
          ecran[11]   := $10FF; { 0001000011111111 }
          ecran[12]   := $30FF; { 0011000011111111 }
          ecran[13]   := $F87F; { 1111100001111111 }
          ecran[14]   := $F87F; { 1111100001111111 }
          ecran[15]   := $F87F; { 1111100001111111 }

          curseur[0]  := $0000; { 0000000000000000 }
          curseur[1]  := $4000; { 0100000000000000 }
          curseur[2]  := $6000; { 0110000000000000 }
          curseur[3]  := $7000; { 0111000000000000 }
          curseur[4]  := $7800; { 0111100000000000 }
          curseur[5]  := $7C00; { 0111110000000000 }
          curseur[6]  := $7E00; { 0111111000000000 }
          curseur[7]  := $7F00; { 0111111100000000 }
          curseur[8]  := $7F80; { 0111111110000000 }
          curseur[9]  := $7FC0; { 0111111111000000 }
          curseur[10] := $7C00; { 0111110000000000 }
          curseur[11] := $4600; { 0100011000000000 }
          curseur[12] := $0600; { 0000011000000000 }
          curseur[13] := $0300; { 0000001100000000 }
          curseur[14] := $0300; { 0000001100000000 }
          curseur[15] := $0000; { 0000000000000000 }
          ptActif.x := 1;
          ptActif.y := 1;
     END;
END;


{}
{    Dfinit un curseur souris en forme de petite flche incline classique.}
{}
PROCEDURE definitFleche_petite;
BEGIN
     WITH Fleche_petite^ DO
     BEGIN
          ecran[0]  := $1FFF;        { 0001111111111111 }
          ecran[1]  := $07FF;        { 0000011111111111 }
          ecran[2]  := $01FF;        { 0000000111111111 }
          ecran[3]  := $00FF;        { 0000000011111111 }
          ecran[4]  := $007F;        { 0000000001111111 }
          ecran[5]  := $01FF;        { 0000000111111111 }
          ecran[6]  := $00FF;        { 0000000011111111 }
          ecran[7]  := $F07F;        { 1111000001111111 }
          ecran[8]  := $FC3F;        { 1111110000111111 }
          ecran[9]  := $FC3F;        { 1111110000111111 }
          ecran[10] := $FFFF;        { 1111111111111111 }
          ecran[11] := $FFFF;        { 1111111111111111 }
          ecran[12] := $FFFF;        { 1111111111111111 }
          ecran[13] := $FFFF;        { 1111111111111111 }
          ecran[14] := $FFFF;        { 1111111111111111 }
          ecran[15] := $FFFF;        { 1111111111111111 }


          curseur[0]  := $0000;      { 0000000000000000 }
          curseur[1]  := $4000;      { 0100000000000000 }
          curseur[2]  := $7000;      { 0111000000000000 }
          curseur[3]  := $7C00;      { 0111110000000000 }
          curseur[4]  := $7F00;      { 0111111100000000 }
          curseur[5]  := $6C00;      { 0110110000000000 }
          curseur[6]  := $0600;      { 0000011000000000 }
          curseur[7]  := $0300;      { 0000001100000000 }
          curseur[8]  := $0180;      { 0000000110000000 }
          curseur[9]  := $0000;      { 0000000000000000 }
          curseur[10] := $0000;      { 0000000000000000 }
          curseur[11] := $0000;      { 0000000000000000 }
          curseur[12] := $0000;      { 0000000000000000 }
          curseur[13] := $0000;      { 0000000000000000 }
          curseur[14] := $0000;      { 0000000000000000 }
          curseur[15] := $0000;      { 0000000000000000 }
          ptActif.x := 1;
          ptActif.y := 1;
     END;
END;


{}
{          Dfinit un curseur souris en forme de flche gauche.             }
{}
PROCEDURE definitFleche_Gauche;
BEGIN
     WITH Fleche_gauche^ DO
     BEGIN
          ecran[0]    := $FE7F; { 1111111001111111 }
          ecran[1]    := $FC7F; { 1111110001111111 }
          ecran[2]    := $F87F; { 1111100001111111 }
          ecran[3]    := $F07F; { 1111000001111111 }
          ecran[4]    := $E000; { 1110000000000000 }
          ecran[5]    := $C000; { 1100000000000000 }
          ecran[6]    := $8000; { 1000000000000000 }
          ecran[7]    := $0000; { 0000000000000000 }
          ecran[8]    := $0000; { 0000000000000000 }
          ecran[9]    := $8000; { 1000000000000000 }
          ecran[10]   := $C000; { 1100000000000000 }
          ecran[11]   := $E000; { 1110000000000000 }
          ecran[12]   := $F07F; { 1111000001111111 }
          ecran[13]   := $F87F; { 1111100001111111 }
          ecran[14]   := $FC7F; { 1111110001111111 }
          ecran[15]   := $FE7F; { 1111111001111111 }

          curseur[0]  := $0000; { 0000000000000000 }
          curseur[1]  := $0100; { 0000000100000000 }
          curseur[2]  := $0300; { 0000001100000000 }
          curseur[3]  := $0700; { 0000011100000000 }
          curseur[4]  := $0F00; { 0000111100000000 }
          curseur[5]  := $1FFE; { 0001111111111110 }
          curseur[6]  := $3FFE; { 0011111111111110 }
          curseur[7]  := $7FFE; { 0111111111111110 }
          curseur[8]  := $7FFE; { 0111111111111110 }
          curseur[9]  := $3FFE; { 0011111111111110 }
          curseur[10] := $1FFE; { 0001111111111110 }
          curseur[11] := $0F00; { 0000111100000000 }
          curseur[12] := $0700; { 0000011100000000 }
          curseur[13] := $0300; { 0000001100000000 }
          curseur[14] := $0100; { 0000000100000000 }
          curseur[15] := $0000; { 0000000000000000 }
          ptActif.x := 1;
          ptActif.y := 7;
     END;
END;

{}
{          Dfinit un curseur souris en forme de flche droite.             }
{}
PROCEDURE definitFleche_Droite;
BEGIN
     WITH Fleche_droite^ DO
     BEGIN
          ecran[0]    := $FE7F; { 1111111001111111 }
          ecran[1]    := $FE3F; { 1111111000111111 }
          ecran[2]    := $FE1F; { 1111111000011111 }
          ecran[3]    := $FE0F; { 1111111000001111 }
          ecran[4]    := $0007; { 0000000000000111 }
          ecran[5]    := $0003; { 0000000000000011 }
          ecran[6]    := $0001; { 0000000000000001 }
          ecran[7]    := $0000; { 0000000000000000 }
          ecran[8]    := $0000; { 0000000000000000 }
          ecran[9]    := $0001; { 0000000000000001 }
          ecran[10]   := $0003; { 0000000000000011 }
          ecran[11]   := $0007; { 0000000000000111 }
          ecran[12]   := $FE0F; { 1111111000001111 }
          ecran[13]   := $FE1F; { 1111111000011111 }
          ecran[14]   := $FE3F; { 1111111000111111 }
          ecran[15]   := $FE7F; { 1111111001111111 }

          curseur[0]  := $0000; { 0000000000000000 }
          curseur[1]  := $0080; { 0000000010000000 }
          curseur[2]  := $00C0; { 0000000011000000 }
          curseur[3]  := $00E0; { 0000000011100000 }
          curseur[4]  := $00F0; { 0000000011110000 }
          curseur[5]  := $7FF8; { 0111111111111000 }
          curseur[6]  := $7FFC; { 0111111111111100 }
          curseur[7]  := $7FFE; { 0111111111111110 }
          curseur[8]  := $7FFE; { 0111111111111110 }
          curseur[9]  := $7FFC; { 0111111111111100 }
          curseur[10] := $7FF8; { 0111111111111000 }
          curseur[11] := $00F0; { 0000000011110000 }
          curseur[12] := $00E0; { 0000000011100000 }
          curseur[13] := $00C0; { 0000000011000000 }
          curseur[14] := $0080; { 0000000010000000 }
          curseur[15] := $0000; { 0000000000000000 }
          ptActif.x := 14;
          ptActif.y := 7;
     END;
END;


PROCEDURE definitmain2;
BEGIN
     WITH main2^ DO
     BEGIN
          ecran[0]    := $FFFF; { 1111111111111111 }
          ecran[1]    := $FFFF; { 1111111111111111 }
          ecran[2]    := $FFFF; { 1111111111111111 }
          ecran[3]    := $F3FF; { 1111001111111111 }
          ecran[4]    := $E1FF; { 1110000111111111 }
          ecran[5]    := $E049; { 1110000001001001 }
          ecran[6]    := $E000; { 1110000000000000 }
          ecran[7]    := $E000; { 1110000000000000 }
          ecran[8]    := $8000; { 1000000000000000 }
          ecran[9]    := $0000; { 0000000000000000 }
          ecran[10]   := $0000; { 0000000000000000 }
          ecran[11]   := $0000; { 0000000000000000 }
          ecran[12]   := $0000; { 0000000000000000 }
          ecran[13]   := $0000; { 0000000000000000 }
          ecran[14]   := $0000; { 0000000000000000 }
          ecran[15]   := $8001; { 1000000000000001 }

          curseur[0]  := $0000; { 0000000000000000 }
          curseur[1]  := $0000; { 0000000000000000 }
          curseur[2]  := $0000; { 0000000000000000 }
          curseur[3]  := $0000; { 0000000000000000 }
          curseur[4]  := $0C00; { 0000110000000000 }
          curseur[5]  := $0C00; { 0000110000000000 }
          curseur[6]  := $0DB6; { 0000110110110110 }
          curseur[7]  := $0DB6; { 0000110110110110 }
          curseur[8]  := $0DB6; { 0000110110110110 }
          curseur[9]  := $6FFE; { 0110111111111110 }
          curseur[10] := $6FFE; { 0110111111111110 }
          curseur[11] := $6FFE; { 0110111111111110 }
          curseur[12] := $7FFE; { 0111111111111110 }
          curseur[13] := $7FFE; { 0111111111111110 }
          curseur[14] := $7FFE; { 0111111111111110 }
          curseur[15] := $0000; { 0000000000000000 }
          ptActif.x := 4;
          ptActif.y := 1;
     END;
END;



{}
{       Dfinit un curseur souris en forme de main  l'index tendu.         }
{}
PROCEDURE definitMain;
BEGIN
     WITH Main^ DO
     BEGIN
          ecran[0]    := $F3FF; { 1111001111111111 }
          ecran[1]    := $E1FF; { 1110000111111111 }
          ecran[2]    := $E1FF; { 1110000111111111 }
          ecran[3]    := $E1FF; { 1110000111111111 }
          ecran[4]    := $E1FF; { 1110000111111111 }
          ecran[5]    := $E049; { 1110000001001001 }
          ecran[6]    := $E000; { 1110000000000000 }
          ecran[7]    := $E000; { 1110000000000000 }
          ecran[8]    := $8000; { 1000000000000000 }
          ecran[9]    := $0000; { 0000000000000000 }
          ecran[10]   := $0000; { 0000000000000000 }
          ecran[11]   := $0000; { 0000000000000000 }
          ecran[12]   := $0000; { 0000000000000000 }
          ecran[13]   := $0000; { 0000000000000000 }
          ecran[14]   := $0000; { 0000000000000000 }
          ecran[15]   := $8001; { 1000000000000001 }

          curseur[0]  := $0000; { 0000000000000000 }
          curseur[1]  := $0C00; { 0000110000000000 }
          curseur[2]  := $0C00; { 0000110000000000 }
          curseur[3]  := $0C00; { 0000110000000000 }
          curseur[4]  := $0C00; { 0000110000000000 }
          curseur[5]  := $0C00; { 0000110000000000 }
          curseur[6]  := $0DB6; { 0000110110110110 }
          curseur[7]  := $0DB6; { 0000110110110110 }
          curseur[8]  := $0DB6; { 0000110110110110 }
          curseur[9]  := $6FFE; { 0110111111111110 }
          curseur[10] := $6FFE; { 0110111111111110 }
          curseur[11] := $6FFE; { 0110111111111110 }
          curseur[12] := $7FFE; { 0111111111111110 }
          curseur[13] := $7FFE; { 0111111111111110 }
          curseur[14] := $7FFE; { 0111111111111110 }
          curseur[15] := $0000; { 0000000000000000 }
          ptActif.x := 4;
          ptActif.y := 1;
     END;
END;


{}
{             Dfinit un curseur souris en forme de sablier.                }
{}
PROCEDURE definitSablier1;
BEGIN
     WITH Sablier1^ DO
     BEGIN
          ecran[0]    := $8003; { 1000000000000011 }
          ecran[1]    := $C007; { 1100000000000111 }
          ecran[2]    := $C007; { 1100000000000111 }
          ecran[3]    := $C007; { 1100000000000111 }
          ecran[4]    := $E00F; { 1110000000001111 }
          ecran[5]    := $E00F; { 1110000000001111 }
          ecran[6]    := $F01F; { 1111000000011111 }
          ecran[7]    := $F83F; { 1111100000111111 }
          ecran[8]    := $F01F; { 1111000000011111 }
          ecran[9]    := $E00F; { 1110000000001111 }
          ecran[10]   := $E00F; { 1110000000001111 }
          ecran[11]   := $C007; { 1100000000000111 }
          ecran[12]   := $C007; { 1100000000000111 }
          ecran[13]   := $C007; { 1100000000000111 }
          ecran[14]   := $8003; { 1000000000000011 }
          ecran[15]   := $FFFF; { 1111111111111111 }

          curseur[0]  := $7FFC; { 0111111111111100 }
          curseur[1]  := $2008; { 0010000000001000 }
          curseur[2]  := $2008; { 0010000000001000 }
          curseur[3]  := $2FE8; { 0010111111101000 }
          curseur[4]  := $17D0; { 0001011111010000 }
          curseur[5]  := $17D0; { 0001011111010000 }
          curseur[6]  := $0BA0; { 0000101110100000 }
          curseur[7]  := $0540; { 0000010101000000 }
          curseur[8]  := $0920; { 0000100100100000 }
          curseur[9]  := $1110; { 0001000100010000 }
          curseur[10] := $1110; { 0001000100010000 }
          curseur[11] := $2008; { 0010000000001000 }
          curseur[12] := $2008; { 0010000000001000 }
          curseur[13] := $2008; { 0010000000001000 }
          curseur[14] := $7FFC; { 0111111111111100 }
          curseur[15] := $0000; { 0000000000000000 }
          ptActif.x := 7;
          ptActif.y := 7;
     END;
END;

PROCEDURE definitSablier2;
BEGIN
     WITH Sablier2^ DO
     BEGIN
          ecran[0]    := $8003; { 1000000000000011 }
          ecran[1]    := $C007; { 1100000000000111 }
          ecran[2]    := $C007; { 1100000000000111 }
          ecran[3]    := $C007; { 1100000000000111 }
          ecran[4]    := $E00F; { 1110000000001111 }
          ecran[5]    := $E00F; { 1110000000001111 }
          ecran[6]    := $F01F; { 1111000000011111 }
          ecran[7]    := $F83F; { 1111100000111111 }
          ecran[8]    := $F01F; { 1111000000011111 }
          ecran[9]    := $E00F; { 1110000000001111 }
          ecran[10]   := $E00F; { 1110000000001111 }
          ecran[11]   := $C007; { 1100000000000111 }
          ecran[12]   := $C007; { 1100000000000111 }
          ecran[13]   := $C007; { 1100000000000111 }
          ecran[14]   := $8003; { 1000000000000011 }
          ecran[15]   := $FFFF; { 1111111111111111 }

          curseur[0]  := $7FFC; { 0111111111111100 }
          curseur[1]  := $2008; { 0010000000001000 }
          curseur[2]  := $2008; { 0010000000001000 }
          curseur[3]  := $2008; { 0010000000001000 }
          curseur[4]  := $1010; { 0001000000010000 }
          curseur[5]  := $17D0; { 0001011111010000 }
          curseur[6]  := $0BA0; { 0000101110100000 }
          curseur[7]  := $0540; { 0000010101000000 }
          curseur[8]  := $0920; { 0000100100100000 }
          curseur[9]  := $1110; { 0001000100010000 }
          curseur[10] := $1110; { 0001000100010000 }
          curseur[11] := $27C8; { 0010011111001000 }
          curseur[12] := $2FE8; { 0010111111101000 }
          curseur[13] := $2008; { 0010000000001000 }
          curseur[14] := $7FFC; { 0111111111111100 }
          curseur[15] := $0000; { 0000000000000000 }
          ptActif.x := 7;
          ptActif.y := 7;
     END;
END;


PROCEDURE definitSablier3;
BEGIN
     WITH Sablier3^ DO
     BEGIN
          ecran[0]    := $8003; { 1000000000000011 }
          ecran[1]    := $C007; { 1100000000000111 }
          ecran[2]    := $C007; { 1100000000000111 }
          ecran[3]    := $C007; { 1100000000000111 }
          ecran[4]    := $E00F; { 1110000000001111 }
          ecran[5]    := $E00F; { 1110000000001111 }
          ecran[6]    := $F01F; { 1111000000011111 }
          ecran[7]    := $F83F; { 1111100000111111 }
          ecran[8]    := $F01F; { 1111000000011111 }
          ecran[9]    := $E00F; { 1110000000001111 }
          ecran[10]   := $E00F; { 1110000000001111 }
          ecran[11]   := $C007; { 1100000000000111 }
          ecran[12]   := $C007; { 1100000000000111 }
          ecran[13]   := $C007; { 1100000000000111 }
          ecran[14]   := $8003; { 1000000000000011 }
          ecran[15]   := $FFFF; { 1111111111111111 }

          curseur[0]  := $7FFC; { 0111111111111100 }
          curseur[1]  := $2008; { 0010000000001000 }
          curseur[2]  := $2008; { 0010000000001000 }
          curseur[3]  := $2008; { 0010000000001000 }
          curseur[4]  := $1010; { 0001000000010000 }
          curseur[5]  := $1010; { 0001000000010000 }
          curseur[6]  := $0820; { 0000100000100000 }
          curseur[7]  := $0440; { 0000010001000000 }
          curseur[8]  := $0920; { 0000100100100000 }
          curseur[9]  := $1390; { 0001001110010000 }
          curseur[10] := $17D0; { 0001011111010000 }
          curseur[11] := $2FE8; { 0010111111101000 }
          curseur[12] := $2FE8; { 0010111111101000 }
          curseur[13] := $2008; { 0010000000001000 }
          curseur[14] := $7FFC; { 0111111111111100 }
          curseur[15] := $0000; { 0000000000000000 }
          ptActif.x := 7;
          ptActif.y := 7;
     END;
END;



{}
{    Dfinit un curseur souris en forme de marque                   .       }
{}
PROCEDURE definitMarque;
BEGIN
     WITH Marque^ DO
     BEGIN
          ecran[0]    := $FFFF; { 1111111111111111 }
          ecran[1]    := $FFF8; { 1111111111111000 }
          ecran[2]    := $FFF0; { 1111111111100000 }
          ecran[3]    := $FFE1; { 1111111111100001 }
          ecran[4]    := $FFC3; { 1111111111000011 }
          ecran[5]    := $FF87; { 1111111111000111 }
          ecran[6]    := $FF87; { 1111111110000111 }
          ecran[7]    := $FF8F; { 1111111110001111 }
          ecran[8]    := $FF0F; { 1111111100001111 }
          ecran[9]    := $071F; { 0000011100011111 }
          ecran[10]   := $001F; { 0000000000011111 }
          ecran[11]   := $003F; { 0000000000111111 }
          ecran[12]   := $C03F; { 1100000000111111 }
          ecran[13]   := $F07F; { 1111000001111111 }
          ecran[14]   := $F87F; { 1111100001111111 }
          ecran[15]   := $FC7F; { 1111110001111111 }


          curseur[0]  := $0000; { 0000000000000000 }
          curseur[1]  := $0000; { 0000000000000000 }
          curseur[2]  := $0002; { 0000000000000010 }
          curseur[3]  := $000C; { 0000000000001100 }
          curseur[4]  := $0008; { 0000000000001000 }
          curseur[5]  := $0010; { 0000000000010000 }
          curseur[6]  := $0010; { 0000000000010000 }
          curseur[7]  := $0020; { 0000000000100000 }
          curseur[8]  := $0020; { 0000000000100000 }
          curseur[9]  := $0040; { 0000000001000000 }
          curseur[10] := $7040; { 0111000001000000 }
          curseur[11] := $1C80; { 0001110010000000 }
          curseur[12] := $0780; { 0000011110000000 }
          curseur[13] := $0300; { 0000001100000000 }
          curseur[14] := $0100; { 0000000100000000 }
          curseur[15] := $0000; { 0000000000000000 }
          ptActif.x := 7;
          ptActif.y := 14
     END;
END;


{}
{    Dfinit un curseur souris en forme de croix rectangulaire      .       }
{}
PROCEDURE definitCroixR;
BEGIN
     WITH CroixR^ DO
     BEGIN
          ecran[0]    := $fc3f; { 1111110000111111 }
          ecran[1]    := $fc3f; { 1111110000111111 }
          ecran[2]    := $fc3f; { 1111110000111111 }
          ecran[3]    := $0000; { 0000000000000000 }
          ecran[4]    := $0000; { 0000000000000000 }
          ecran[5]    := $0000; { 0000000000000000 }
          ecran[6]    := $fc3F; { 1111110000111111 }
          ecran[7]    := $fc3f; { 1111110000111111 }
          ecran[8]    := $fc3f; { 1111110000111111 }
          ecran[9]    := $ffff; { 1111111111111111 }
          ecran[10]   := $ffff; { 1111111111111111 }
          ecran[11]   := $ffff; { 1111111111111111 }
          ecran[12]   := $ffff; { 1111111111111111 }
          ecran[13]   := $ffff; { 1111111111111111 }
          ecran[14]   := $ffff; { 1111111111111111 }
          ecran[15]   := $ffff; { 1111111111111111 }

          curseur[0]  := $0000; { 0000000000000000 }
          curseur[1]  := $0180; { 0000000110000000 }
          curseur[2]  := $0180; { 0000000110000000 }
          curseur[3]  := $0180; { 0000000110000000 }
          curseur[4]  := $7ffe; { 0111111111111110 }
          curseur[5]  := $0180; { 0000000110000000 }
          curseur[6]  := $0180; { 0000000110000000 }
          curseur[7]  := $0180; { 0000000110000000 }
          curseur[8]  := $0000; { 0000000000000000 }
          curseur[9]  := $0000; { 0000000000000000 }
          curseur[10] := $0000; { 0000000000000000 }
          curseur[11] := $0000; { 0000000000000000 }
          curseur[12] := $0000; { 0000000000000000 }
          curseur[13] := $0000; { 0000000000000000 }
          curseur[14] := $0000; { 0000000000000000 }
          curseur[15] := $0000; { 0000000000000000 }
          ptActif.x := 7;
          ptActif.y := 4;
     END;
END;


{}
{    Dfinit un curseur souris en forme de croix diagonale.                 }
{}
PROCEDURE definitCroixD;
BEGIN
     WITH CroixD^ DO
     BEGIN
          ecran[0]    := $07e0; { 0000011111100000 }
          ecran[1]    := $0180; { 0000000110000000 }
          ecran[2]    := $0000; { 0000000000000000 }
          ecran[3]    := $c003; { 1100000000000011 }
          ecran[4]    := $f00f; { 1111000000001111 }
          ecran[5]    := $c003; { 1100000000000011 }
          ecran[6]    := $0000; { 0000000000000000 }
          ecran[7]    := $0180; { 0000000110000000 }
          ecran[8]    := $07e0; { 0000011111000000 }
          ecran[9]    := $ffff; { 1111111111111111 }
          ecran[10]   := $ffff; { 1111111111111111 }
          ecran[11]   := $ffff; { 1111111111111111 }
          ecran[12]   := $ffff; { 1111111111111111 }
          ecran[13]   := $ffff; { 1111111111111111 }
          ecran[14]   := $ffff; { 1111111111111111 }
          ecran[15]   := $ffff; { 1111111111111111 }

          curseur[0]  := $0000; { 0000000000000000 }
          curseur[1]  := $700e; { 0111000000001110 }
          curseur[2]  := $1c38; { 0001110000111000 }
          curseur[3]  := $0660; { 0000011001100000 }
          curseur[4]  := $03c0; { 0000000111100000 }
          curseur[5]  := $0660; { 0000001100110000 }
          curseur[6]  := $1c38; { 0001110000111000 }
          curseur[7]  := $700e; { 0111000000001110 }
          curseur[8]  := $0000; { 0000000000000000 }
          curseur[9]  := $0000; { 0000000000000000 }
          curseur[10] := $0000; { 0000000000000000 }
          curseur[11] := $0000; { 0000000000000000 }
          curseur[12] := $0000; { 0000000000000000 }
          curseur[13] := $0000; { 0000000000000000 }
          curseur[14] := $0000; { 0000000000000000 }
          curseur[15] := $0000; { 0000000000000000 }
          ptActif.x := 7;
          ptActif.y := 4;
     END;
END;

PROCEDURE definitReticule;
BEGIN
     WITH Reticule^ DO
     BEGIN
          ecran[0]    := $0001; { 0000000000000001 }
          ecran[1]    := $0001; { 0000000000000001 }
          ecran[2]    := $3FF9; { 0011111111111001 }
          ecran[3]    := $3EF9; { 0011111011111001 }
          ecran[4]    := $3EF9; { 0011111011111001 }
          ecran[5]    := $3EF9; { 0011111011111001 }
          ecran[6]    := $3FF9; { 0011111111111001 }
          ecran[7]    := $2389; { 0010001110001001 }
          ecran[8]    := $3FF9; { 0011111111111001 }
          ecran[9]    := $3EF9; { 0011111011111001 }
          ecran[10]   := $3EF9; { 0011111011111001 }
          ecran[11]   := $3EF9; { 0011111011111001 }
          ecran[12]   := $3FF9; { 0011111111111001 }
          ecran[13]   := $0001; { 0000000000000001 }
          ecran[14]   := $0001; { 0000000000000001 }
          ecran[15]   := $FFFF; { 1111111111111111 }

          curseur[0]  := $0001; { 0000000000000001 }
          curseur[1]  := $7FFD; { 0111111111111101 }
          curseur[2]  := $4005; { 0100000000000101 }
          curseur[3]  := $4005; { 0100000000000101 }
          curseur[4]  := $4005; { 0100000000000101 }
          curseur[5]  := $4005; { 0100000000000101 }
          curseur[6]  := $4005; { 0100000000000101 }
          curseur[7]  := $4005; { 0100000000000101 }
          curseur[8]  := $4005; { 0100000000000101 }
          curseur[9]  := $4005; { 0100000000000101 }
          curseur[10] := $4005; { 0100000000000101 }
          curseur[11] := $4005; { 0100000000000101 }
          curseur[12] := $4005; { 0100000000000101 }
          curseur[13] := $7FFD; { 0111111111111101 }
          curseur[14] := $0001; { 0000000000000001 }
          curseur[15] := $FFFF; { 1111111111111111 }
          ptActif.x := 7;
          ptActif.y := 7;
     END;
END;



(*************************** INITMOUSE **************************************)
(*initialize the mouse driver, if present, and return the number of buttons.*)
(****************************************************************************)

procedure initmouse(var buttons : word; var err : boolean);
begin
  reg.ax := 0;
  intr(mouseint, reg);
  buttons := reg.bx;
  if (reg.ax = 0) then
    err := true
  else
     begin
     new(un);
     definitun;
     new(unbis);
     definitunbis;
     new(deux);
     definitdeux;
     new(trois);
     definittrois;
     new(quatre);
     definitquatre;
     new(cinq);
     definitcinq;
     new(zero);
     definitzero;
     new(tete_mort);
     definittete_mort;
     new(tete_mort2);
     definittete_mort2;
     new(main2);
     definitmain2;
     new(interrogation);
     definitinterrogation;
     new(cbn);
     definitcbn;
     New(Standard);
     definitStandard;
     New(Fleche_gauche);
     definitFleche_Gauche;
     New(Fleche_droite);
     definitFleche_Droite;
     New(Main);
     definitMain;
     New(Sablier1);
     definitSablier1;
     New(Sablier2);
     definitSablier2;
     New(Sablier3);
     definitSablier3;
     New(Marque);
     definitMarque;
     New(CroixR);
     definitCroixR;
     New(CroixD);
     definitCroixD;
     New(Fleche_petite);
     definitFleche_petite;
     New(Reticule);
     definitReticule;
     err := false;
     end;
end;



(********************************* SHOWPOINTER ******************************)
procedure showpointer;
begin
  reg.ax := 1;
  intr(mouseint, reg);
end;



(********************************** HIDEPOINTER *****************************)
procedure hidepointer;
begin
  reg.ax := 2;
  intr(mouseint, reg);
end;



(************************************ BUTTONPRESSED *************************)
function buttonpressed(mask : word) : boolean;
begin
  reg.ax := 3;
  intr(mouseint, reg);
  if (reg.bx > 0) then
    buttonpressed := true
  else
    buttonpressed := false;
end;



(******************************** GETMOUSEPOSITION **************************)
procedure getmouseposition(var buttons, horiz, vert : word);
begin
  reg.ax := 3;
  intr(mouseint, reg);
  buttons := reg.bx;
  horiz := reg.cx;
  vert := reg.dx;
end;



(****************************** MOUSEIN *************************************)
function mousein(x1,y1,x2,y2: word):boolean;
var b,x,y: word;
begin
  getmouseposition(b,x,y);
  mousein:=(x>=x1) and (x<=x2) and (y>=y1) and (y<=y2)
end;



(*************************** SETPOINTERPOSITION *****************************)
procedure setpointerposition(horiz, vert : word);
begin
  reg.ax := 4;
  reg.cx := horiz;
  reg.dx := vert;
  intr(mouseint, reg);
end;




(***************************** GETPRESSINFO *********************************)
procedure getpressinfo(button : word; var stat, count, horiz, vert : word);
begin
  reg.ax := 5;
  reg.bx := button;
  intr(mouseint, reg);
  stat := reg.ax;
  count := reg.bx;
  horiz := reg.cx;
  vert := reg.dx;
end;



(******************************* GETRELEASEINFO *****************************)
procedure getreleaseinfo(button : word; var stat, count, horiz, vert : word);
begin
  reg.ax := 6;
  reg.bx := button;
  intr(mouseint, reg);
  stat := reg.ax;
  count := reg.bx;
  horiz := reg.cx;
  vert := reg.dx;
end;



(****************************** SETLIMITS ***********************************)
procedure setlimits(hormin, hormax, vermin, vermax : word);
begin
  if (hormin > 0) and (hormax > 0) then
    begin
      reg.ax := 7;
      reg.cx := hormin;
      reg.dx := hormax;
      intr(mouseint, reg);
    end;
  if (vermin > 0) and (vermax > 0) then
    begin
      reg.ax := 8;
      reg.cx := vermin;
      reg.dx := vermax;
      intr(mouseint, reg);
    end;
end;



(************************ SETPOINTERSHAPE ***********************************)
procedure setpointershape(LaForme : FormePtr);
BEGIN
     WITH reg DO
          WITH laForme^ DO
          BEGIN
               AX := 9;
               BX := ptActif.x;
               CX := ptActif.y;
               DX := Ofs(ecran[0]);
               ES := Seg(ecran[0]);
          END;
     Intr($33,reg);
END;



(***************************** GETMOTIONCOUNT *******************************)
procedure getmotioncount(var horiz, vert : word);
begin
  reg.ax := 11;
  intr(mouseint, reg);
  horiz := reg.cx;
  vert := reg.dx;
end;



(******************************* SETEVENTHANDLER ****************************)
procedure seteventhandler(eventmask : word; handler : pointer);
begin
  reg.ax := 12;
  reg.cx := eventmask;
  reg.es := seg(handler);
  reg.dx := ofs(handler);
  intr(mouseint, reg);
end;



(************************* SETPOINTEREXCL ***********************************)
procedure setpointerexcl(hormin, vermin, hormax, vermax : word);
begin
  reg.ax := 16;
  reg.cx := hormin;
  reg.si := hormax;
  reg.dx := vermin;
  reg.di := vermax;
  intr(mouseint, reg);
end;



(******************************** SWAPEVENTHANDLERS *************************)
procedure swapeventhandlers(var mask : word; var buffer : pointer);
begin
  reg.ax := 20;
  reg.cx := mask;
  reg.es := seg(buffer);
  reg.dx := ofs(buffer);
  intr(mouseint, reg);
  mask := reg.cx;
  buffer := ptr(reg.es, reg.dx);
end;



(************************** GETSAVESTATESIZE ********************************)
function getsavestatesize : word;
begin
  reg.ax := 21;
  intr(mouseint, reg);
  getsavestatesize := reg.bx;
end;



(***************************** SETDRVRSTATE *********************************)
procedure savedrvrstate(buffer : pointer);
begin
  reg.ax := 22;
  reg.es := seg(buffer);
  reg.dx := ofs(buffer);
  intr(mouseint, reg);
end;



(********************************* RESTOREDRVRSTATE *************************)
procedure restoredrvrstate(buffer : pointer);
begin
  reg.ax := 23;
  reg.es := seg(buffer);
  reg.dx := ofs(buffer);
  intr(mouseint, reg);
end;



(****************************** SETEVENTHANDLER *****************************)
procedure setalteventhandler(mask : word; handler : pointer; var err:boolean);
begin
  reg.ax := 24;
  reg.cx := mask;
  reg.es := seg(handler);
  reg.dx := ofs(handler);
  intr(mouseint, reg);
  if (reg.ax = 24) then
    err := false
  else
    err := true;
end;



(**************************** GETALTEVENTADRS *******************************)
procedure getalteventadrs(var mask:word;var handler:pointer;var err:boolean);
begin
  reg.ax := 25;
  reg.cx := mask;
  intr(mouseint, reg);
  if (reg.cx > 0) then
    begin
      mask := reg.cx;
      handler := ptr(reg.es, reg.dx);
      err := false;
    end
  else
    err := true;
end;




(************************** SETMOUSESENSE ***********************************)
procedure setmousesense(horiz, vert, double : word);
begin
  reg.ax := 26;
  reg.bx := horiz;
  reg.cx := vert;
  reg.dx := double;
  intr(mouseint, reg);
end;




(**************************** GETMOUSESENSE *********************************)
procedure getmousesense(var horiz, vert, double : word);
begin
  reg.ax := 27;
  intr(mouseint, reg);
  horiz := reg.bx;
  vert := reg.cx;
  double := reg.dx;
end;




(********************************* SETMOUSEINTR *****************************)
procedure setmouseintr(flags : word);
begin
  reg.ax := 28;
  reg.bx := flags;
  intr(mouseint, reg);
end;



(************************************ SETPOINTERPAGE ************************)
procedure setpointerpage(page : word);
begin
  reg.ax := 29;
  reg.bx := page;
  intr(mouseint, reg);
end;




(**************************** GETPOINTERPAGE ********************************)
function getpointerpage : word;
begin
  reg.ax := 30;
  intr(mouseint, reg);
  getpointerpage := reg.bx;
end;




(****************************** DISABLEMOUSEDRVR ****************************)
procedure disablemousedrvr(var handler : pointer; var err : boolean);
begin
  reg.ax := 31;
  intr(mouseint, reg);
  if (reg.ax = 31) then
    begin
      handler := ptr(reg.es, reg.dx);
      err := false;
    end
  else
    err := true;
end;




(***************************** ENABLEMOUSEDRVR ******************************)
procedure enablemousedrvr;
begin
  reg.ax := 32;
  intr(mouseint, reg);
end;



(******************************* RESETMOUSEDRVR *****************************)
procedure resetmousedrvr(var buttons : word; var err : boolean);
begin
  reg.ax := 33;
  intr(mouseint, reg);
  if (reg.ax = $ffff) then
    begin
      buttons := reg.bx;
      err := false;
    end
  else
    err := true;
end;




(**************************** SETMOUSELANG **********************************)
procedure setmouselang(langnumber : word);
begin
  reg.ax := 34;
  reg.bx := langnumber;
  intr(mouseint, reg);
end;




(***************************** GETMOUSELANG *********************************)
function getmouselang : word;
begin
  reg.ax := 35;
  intr(mouseint, reg);
  getmouselang := reg.bx;
end;




(****************************** GETMOUSEINFO ********************************)
procedure getmouseinfo(var majver, minver, mousetype, irq : word);
begin
  reg.ax := 36;
  intr(mouseint, reg);
  majver := reg.bh;
  minver := reg.bl;
  mousetype := reg.ch;
  irq := reg.cl;
end;

end.
